@@ -13,4 +13,4 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from stomp import StompHubExtension
+from moksha.hub.stomp.stomp import StompHubExtension
